package com.ruoyi.generator.service;


import com.ruoyi.generator.domain.SysProjectTable;

import java.util.List;

/**
 * 项目与表关联Service接口
 *
 * @author ruoyi
 * @date {DATE}
 */
public interface ISysProjectTableService
{
    /**
     * 查询项目与表关联
     *
     * @param id 项目与表关联主键
     * @return 项目与表关联
     */
    public SysProjectTable selectSysProjectTableById(Long id);

    /**
     * 查询项目与表关联列表
     *
     * @param sysProjectTable 项目与表关联
     * @return 项目与表关联集合
     */
    public List<SysProjectTable> selectSysProjectTableList(SysProjectTable sysProjectTable);

    /**
     * 新增项目与表关联
     *
     * @param sysProjectTable 项目与表关联
     * @return 结果
     */
    public int insertSysProjectTable(SysProjectTable sysProjectTable);

    /**
     * 修改项目与表关联
     *
     * @param sysProjectTable 项目与表关联
     * @return 结果
     */
    public int updateSysProjectTable(SysProjectTable sysProjectTable);

    /**
     * 批量删除项目与表关联
     *
     * @param ids 需要删除的项目与表关联主键集合
     * @return 结果
     */
    public int deleteSysProjectTableByIds(Long[] ids);

    /**
     * 删除项目与表关联信息
     *
     * @param id 项目与表关联主键
     * @return 结果
     */
    public int deleteSysProjectTableById(Long id);

    /**
     * 根据项目ID删除关联关系
     *
     * @param projectId 项目ID
     * @return 结果
     */
    public int deleteSysProjectTableByProjectId(Long projectId);

    /**
     * 根据表ID删除关联关系
     *
     * @param tableId 表ID
     * @return 结果
     */
    public int deleteSysProjectTableByTableId(Long tableId);
} 